@@ -916,9 +916,9 @@ g_local_file_query_filesystem_info (GFile         *file,
   gboolean no_size;
 #ifndef G_OS_WIN32
   guint64 block_size;
+  const char *fstype;
 #ifdef USE_STATFS
   struct statfs statfs_buffer;
-  const char *fstype;
 #elif defined(USE_STATVFS)
   struct statvfs statfs_buffer;
 #endif
@@ -968,7 +968,8 @@ g_local_file_query_filesystem_info (GFile         *file,
 
   attribute_matcher = g_file_attribute_matcher_new (attributes);
   
-  if (g_file_attribute_matcher_matches (attribute_matcher,
+  if (!no_size &&
+      g_file_attribute_matcher_matches (attribute_matcher,
 					G_FILE_ATTRIBUTE_FILESYSTEM_FREE))
     {
 #ifdef G_OS_WIN32
@@ -984,7 +985,8 @@ g_local_file_query_filesystem_info (GFile         *file,
       g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE, block_size * statfs_buffer.f_bavail);
 #endif
     }
-  if (g_file_attribute_matcher_matches (attribute_matcher,
+  if (!no_size &&
+      g_file_attribute_matcher_matches (attribute_matcher,
 					G_FILE_ATTRIBUTE_FILESYSTEM_SIZE))
     {
 #ifdef G_OS_WIN32
@@ -1006,6 +1008,12 @@ g_local_file_query_filesystem_info (GFile         *file,
 #else
   fstype = get_fs_type (statfs_buffer.f_type);
 #endif
+
+#elif defined(USE_STATVFS) && defined(HAVE_STRUCT_STATVFS_F_BASETYPE)
+  fstype = g_strdup(statfs_buffer.f_basetype); 
+#endif
+
+#ifndef G_OS_WIN32
   if (fstype &&
       g_file_attribute_matcher_matches (attribute_matcher,
 					G_FILE_ATTRIBUTE_FILESYSTEM_TYPE))
@@ -1580,7 +1588,8 @@ escape_trash_name (char *name)
 gboolean
 _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
 {
-  static gsize home_dev = 0;
+  static gsize home_dev_set = 0;
+  static dev_t home_dev;
   char *topdir, *globaldir, *trashdir, *tmpname;
   uid_t uid;
   char uid_str[32];
@@ -1588,18 +1597,17 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
   gboolean res;
   int statres;
       
-  if (g_once_init_enter (&home_dev))
+  if (g_once_init_enter (&home_dev_set))
     {
-      gsize setup_value = 0;
       struct stat home_stat;
       
       g_stat (g_get_home_dir (), &home_stat);
-      setup_value = home_stat.st_dev;
-      g_once_init_leave (&home_dev, setup_value);
+      home_dev = home_stat.st_dev;
+      g_once_init_leave (&home_dev_set, 1);
     }
 
   /* Assume we can trash to the home */
-  if (dir_dev == (dev_t)home_dev)
+  if (dir_dev == home_dev)
     return TRUE;
 
   topdir = find_mountpoint_for (dirname, dir_dev);
@@ -1986,7 +1994,7 @@ g_local_file_make_directory (GFile         *file,
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
-		     _("Error removing file: %s"),
+		     _("Error creating directory: %s"),
 		     g_strerror (errsv));
       return FALSE;
     }
