@@ -275,7 +275,6 @@ guess_system_internal (const char *mountpoint,
     "usbfs",
     "nfsd",
     "rpc_pipefs",
-    "zfs",
     NULL
   };
   const char *ignore_devices[] = {
@@ -1232,10 +1231,37 @@ g_unix_mount_monitor_init (GUnixMountMonitor *monitor)
     }
 }
 
+/**
+ * g_unix_mount_monitor_set_rate_limit:
+ * @mount_monitor: a #GUnixMountMonitor.
+ * @limit_msecs: a integer with the limit in milliseconds to
+ * poll for changes.
+ *
+ * Sets the rate limit to which the @mount_monitor will report
+ * consecutive change events to the mount and mount point entry files.
+ *
+ * Since: 2.18
+ **/
+void
+g_unix_mount_monitor_set_rate_limit (GUnixMountMonitor *mount_monitor,
+                                     int                limit_msec)
+{
+  g_return_if_fail (G_IS_UNIX_MOUNT_MONITOR (mount_monitor));
+
+  if (mount_monitor->fstab_monitor != NULL)
+    g_file_monitor_set_rate_limit (mount_monitor->fstab_monitor, limit_msec);
+
+  if (mount_monitor->mtab_monitor != NULL)
+    g_file_monitor_set_rate_limit (mount_monitor->mtab_monitor, limit_msec);
+}
+
 /**
  * g_unix_mount_monitor_new:
  * 
- * Gets a new #GUnixMountMonitor.
+ * Gets a new #GUnixMountMonitor. The default rate limit for which the
+ * monitor will report consecutive changes for the mount and mount
+ * point entry files is the default for a #GFileMonitor. Use
+ * g_unix_mount_monitor_set_rate_limit() to change this.
  * 
  * Returns: a #GUnixMountMonitor. 
  **/
@@ -1601,27 +1627,10 @@ guess_mount_type (const char *mount_path,
     {
       basename = g_path_get_basename (mount_path);
       
-      if (g_str_has_prefix (basename, "cdrom") ||
+      if (g_str_has_prefix (basename, "cdr") ||
 	  g_str_has_prefix (basename, "cdwriter") ||
 	  g_str_has_prefix (basename, "burn") ||
-	  g_str_has_prefix (basename, "cdr") ||
-	  g_str_has_prefix (basename, "cdrw") ||
-	  g_str_has_prefix (basename, "dvdrom") ||
-	  g_str_has_prefix (basename, "dvdram") ||
-	  g_str_has_prefix (basename, "dvdr") ||
-	  g_str_has_prefix (basename, "dvdrw") ||
-	  g_str_has_prefix (basename, "cdrom_dvdrom") ||
-	  g_str_has_prefix (basename, "cdrom_dvdram") ||
-	  g_str_has_prefix (basename, "cdrom_dvdr") ||
-	  g_str_has_prefix (basename, "cdrom_dvdrw") ||
-	  g_str_has_prefix (basename, "cdr_dvdrom") ||
-	  g_str_has_prefix (basename, "cdr_dvdram") ||
-	  g_str_has_prefix (basename, "cdr_dvdr") ||
-	  g_str_has_prefix (basename, "cdr_dvdrw") ||
-	  g_str_has_prefix (basename, "cdrw_dvdrom") ||
-	  g_str_has_prefix (basename, "cdrw_dvdram") ||
-	  g_str_has_prefix (basename, "cdrw_dvdr") ||
-	  g_str_has_prefix (basename, "cdrw_dvdrw"))
+	  g_str_has_prefix (basename, "dvdr"))
 	type = G_UNIX_MOUNT_TYPE_CDROM;
       else if (g_str_has_prefix (basename, "floppy"))
 	type = G_UNIX_MOUNT_TYPE_FLOPPY;
