@@ -217,7 +217,8 @@ g_base64_encode_close (gboolean  break_lines,
  * representation.
  *
  * Return value: a newly allocated, zero-terminated Base-64 encoded
- *               string representing @data.
+ *               string representing @data. The returned string must 
+ *               be freed with g_free().
  *
  * Since: 2.12
  */
@@ -230,16 +231,14 @@ g_base64_encode (const guchar *data,
   gint save = 0;
 
   g_return_val_if_fail (data != NULL, NULL);
-  g_return_val_if_fail (len > 1, NULL);
+  g_return_val_if_fail (len > 0, NULL);
 
   /* We can use a smaller limit here, since we know the saved state is 0 */
   out = g_malloc (len * 4 / 3 + 4);
   outlen = g_base64_encode_step (data, len, FALSE, out, &state, &save);
-  outlen += g_base64_encode_close (FALSE,
-				   out + outlen, 
-				   &state, 
-				   &save);
+  outlen += g_base64_encode_close (FALSE, out + outlen, &state, &save);
   out[outlen] = '\0';
+
   return (gchar *) out;
 }
 
@@ -349,7 +348,8 @@ g_base64_decode_step (const gchar  *in,
  * Decode a sequence of Base-64 encoded text into binary data
  *
  * Return value: a newly allocated buffer containing the binary data
- *               that @text represents
+ *               that @text represents. The returned buffer must
+ *               be freed with g_free().
  *
  * Since: 2.12
  */
