@@ -16,10 +16,11 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
 #ifndef __G_I18N_LIB_H__
 #define __G_I18N_LIB_H__
 
-#include <glib/gstrfuncs.h>
+#include <glib.h>
 
 #include <libintl.h>
 
@@ -32,5 +33,4 @@
 #define N_(String) (String)
 #define C_(Context,String) g_dpgettext (GETTEXT_PACKAGE, Context "\004" String, strlen (Context) + 1)
 
-
 #endif  /* __G_I18N_LIB_H__ */
