@@ -366,6 +366,7 @@ parse_args (gint    *argc_p,
  *        Changed if any arguments were handled.
  * @argv: Address of the @argv parameter of main().
  *        Any parameters understood by g_test_init() stripped before return.
+ * @Varargs: Reserved for future extension. Currently, you must pass %NULL.
  *
  * Initialize the GLib testing framework, e.g. by seeding the
  * test random number generator, the name for g_get_prgname()
@@ -388,6 +389,8 @@ parse_args (gint    *argc_p,
  * --GTestLogFD N       gtester specific argument.
  * --GTestSkipCount N   gtester specific argument.
  * </informalexample>
+ *
+ * Since: 2.16
  */
 void
 g_test_init (int    *argc,
@@ -481,8 +484,8 @@ test_run_seed (const gchar *rseed)
 /**
  * g_test_rand_int:
  *
- * Get a reproducable random integer number.
- * The random numbers generate by the g_test_rand_*() family of functions
+ * Get a reproducible random integer number.
+ * The random numbers generated by the g_test_rand_*() family of functions
  * change with every new test program start, unless the --seed option is
  * given when starting test programs.
  * For individual test cases however, the random number generator is
@@ -490,6 +493,8 @@ test_run_seed (const gchar *rseed)
  * effective for all test cases.
  *
  * Returns: a random number from the seeded random number generator.
+ *
+ * Since: 2.16
  */
 gint32
 g_test_rand_int (void)
@@ -502,10 +507,12 @@ g_test_rand_int (void)
  * @begin: the minimum value returned by this function
  * @end:   the smallest value not to be returned by this function
  *
- * Get a reproducable random integer number out of a specified range,
+ * Get a reproducible random integer number out of a specified range,
  * see g_test_rand_int() for details on test case random numbers.
  *
  * Returns: a number with @begin <= number < @end.
+ * 
+ * Since: 2.16
  */
 gint32
 g_test_rand_int_range (gint32          begin,
@@ -517,10 +524,12 @@ g_test_rand_int_range (gint32          begin,
 /**
  * g_test_rand_double:
  *
- * Get a reproducable random floating point number,
+ * Get a reproducible random floating point number,
  * see g_test_rand_int() for details on test case random numbers.
  *
- * Return a random number from the seeded random number generator.
+ * Returns: a random number from the seeded random number generator.
+ *
+ * Since: 2.16
  */
 double
 g_test_rand_double (void)
@@ -533,10 +542,12 @@ g_test_rand_double (void)
  * @range_start: the minimum value returned by this function
  * @range_end: the minimum value not returned by this function
  *
- * Get a reproducable random floating pointer number out of a specified range,
+ * Get a reproducible random floating pointer number out of a specified range,
  * see g_test_rand_int() for details on test case random numbers.
  *
  * Returns: a number with @range_start <= number < @range_end.
+ *
+ * Since: 2.16
  */
 double
 g_test_rand_double_range (double          range_start,
@@ -550,6 +561,8 @@ g_test_rand_double_range (double          range_start,
  *
  * Start a timing test. Call g_test_timer_elapsed() when the task is supposed
  * to be done. Call this function again to restart the timer.
+ *
+ * Since: 2.16
  */
 void
 g_test_timer_start (void)
@@ -566,6 +579,8 @@ g_test_timer_start (void)
  * Get the time since the last start of the timer with g_test_timer_start().
  *
  * Returns: the time since the last start of the timer, as a double
+ *
+ * Since: 2.16
  */
 double
 g_test_timer_elapsed (void)
@@ -580,6 +595,8 @@ g_test_timer_elapsed (void)
  * Report the last result of g_test_timer_elapsed().
  *
  * Returns: the last result of g_test_timer_elapsed(), as a double
+ *
+ * Since: 2.16
  */
 double
 g_test_timer_last (void)
@@ -591,12 +608,15 @@ g_test_timer_last (void)
  * g_test_minimized_result:
  * @minimized_quantity: the reported value
  * @format: the format string of the report message
+ * @Varargs: arguments to pass to the printf() function
  *
  * Report the result of a performance or measurement test.
  * The test should generally strive to minimize the reported
  * quantities (smaller values are better than larger ones),
  * this and @minimized_quantity can determine sorting
  * order for test result reports.
+ *
+ * Since: 2.16
  */
 void
 g_test_minimized_result (double          minimized_quantity,
@@ -617,12 +637,15 @@ g_test_minimized_result (double          minimized_quantity,
  * g_test_maximized_result:
  * @maximized_quantity: the reported value
  * @format: the format string of the report message
+ * @Varargs: arguments to pass to the printf() function
  *
  * Report the result of a performance or measurement test.
  * The test should generally strive to maximize the reported
  * quantities (larger values are better than smaller ones),
  * this and @maximized_quantity can determine sorting
  * order for test result reports.
+ *
+ * Since: 2.16
  */
 void
 g_test_maximized_result (double          maximized_quantity,
@@ -645,6 +668,8 @@ g_test_maximized_result (double          maximized_quantity,
  * @...:    printf-like arguments to @format
  *
  * Add a message to the test report.
+ *
+ * Since: 2.16
  */
 void
 g_test_message (const char *format,
@@ -673,6 +698,8 @@ g_test_message (const char *format,
  * Bug URIs are constructed by appending a bug specific URI
  * portion to @uri_pattern, or by replacing the special string
  * '%s' within @uri_pattern if that is present.
+ *
+ * Since: 2.16
  */
 void
 g_test_bug_base (const char *uri_pattern)
@@ -689,6 +716,8 @@ g_test_bug_base (const char *uri_pattern)
  * associates a bug URI with a test case.
  * Bug URIs are constructed from a base URI set with g_test_bug_base()
  * and @bug_uri_snippet.
+ *
+ * Since: 2.16
  */
 void
 g_test_bug (const char *bug_uri_snippet)
@@ -715,6 +744,8 @@ g_test_bug (const char *bug_uri_snippet)
  * Get the toplevel test suite for the test path API.
  *
  * Returns: the toplevel #GTestSuite
+ *
+ * Since: 2.16
  */
 GTestSuite*
 g_test_get_root (void)
@@ -740,6 +771,8 @@ g_test_get_root (void)
  * in a program.
  *
  * Returns: 0 on success
+ *
+ * Since: 2.16
  */
 int
 g_test_run (void)
@@ -764,6 +797,7 @@ g_test_run (void)
  * function data_test() is called. Once the test run completed, the
  * fixture structure is torn down  by calling data_teardown() and
  * after that the memory is released.
+ *
  * Splitting up a test run into fixture setup, test function and
  * fixture teardown is most usful if the same fixture is used for
  * multiple tests. In this cases, g_test_create_case() will be
@@ -771,6 +805,8 @@ g_test_run (void)
  * @data_test arguments.
  *
  * Returns: a newly allocated #GTestCase.
+ *
+ * Since: 2.16
  */
 GTestCase*
 g_test_create_case (const char     *test_name,
@@ -838,13 +874,15 @@ g_test_add_vtable (const char     *testpath,
 
 /**
  * g_test_add_func:
- * @testpath:   Slash seperated test case path name for the test.
+ * @testpath:   Slash-separated test case path name for the test.
  * @test_func:  The test function to invoke for this test.
  *
  * Create a new test case, similar to g_test_create_case(). However
  * the test is assumed to use no fixture, and test suites are automatically
  * created on the fly and added to the root fixture, based on the
- * slash seperated portions of @testpath.
+ * slash-separated portions of @testpath.
+ *
+ * Since: 2.16
  */
 void
 g_test_add_func (const char     *testpath,
@@ -858,15 +896,17 @@ g_test_add_func (const char     *testpath,
 
 /**
  * g_test_add_data_func:
- * @testpath:   Slash separated test case path name for the test.
+ * @testpath:   Slash-separated test case path name for the test.
  * @test_data:  Test data argument for the test function.
  * @test_func:  The test function to invoke for this test.
  *
  * Create a new test case, similar to g_test_create_case(). However
  * the test is assumed to use no fixture, and test suites are automatically
  * created on the fly and added to the root fixture, based on the
- * slash seperated portions of @testpath. The @test_data argument
+ * slash-separated portions of @testpath. The @test_data argument
  * will be passed as first argument to @test_func.
+ *
+ * Since: 2.16
  */
 void
 g_test_add_data_func (const char     *testpath,
@@ -886,6 +926,8 @@ g_test_add_data_func (const char     *testpath,
  * Create a new test suite with the name @suite_name.
  *
  * Returns: A newly allocated #GTestSuite instance.
+ *
+ * Since: 2.16
  */
 GTestSuite*
 g_test_create_suite (const char *suite_name)
@@ -905,6 +947,8 @@ g_test_create_suite (const char *suite_name)
  * @test_case: a #GTestCase
  *
  * Adds @test_case to @suite.
+ *
+ * Since: 2.16
  */
 void
 g_test_suite_add (GTestSuite     *suite,
@@ -921,6 +965,8 @@ g_test_suite_add (GTestSuite     *suite,
  * @nestedsuite: another #GTestSuite
  *
  * Adds @nestedsuite to @suite.
+ *
+ * Since: 2.16
  */
 void
 g_test_suite_add_suite (GTestSuite     *suite,
@@ -938,6 +984,8 @@ g_test_suite_add_suite (GTestSuite     *suite,
  * Enqueue a pointer to be released with g_free() during the next
  * teardown phase. This is equivalent to calling g_test_queue_destroy()
  * with a destroy callback of g_free().
+ *
+ * Since: 2.16
  */
 void
 g_test_queue_free (gpointer gfree_pointer)
@@ -957,6 +1005,8 @@ g_test_queue_free (gpointer gfree_pointer)
  * Resources are released in reverse queue order, that means enqueueing
  * callback A before callback B will cause B() to be called before
  * A() during teardown.
+ *
+ * Since: 2.16
  */
 void
 g_test_queue_destroy (GDestroyNotify destroy_func,
@@ -1073,6 +1123,8 @@ g_test_run_suite_internal (GTestSuite *suite,
  * in a program.
  *
  * Returns: 0 on success
+ *
+ * Since: 2.16
  */
 int
 g_test_run_suite (GTestSuite *suite)
@@ -1229,6 +1281,10 @@ g_assertion_message_cmpstr (const char     *domain,
  * @str2: another C string or %NULL
  *
  * Compares @str1 and @str2 like strcmp(). Handles %NULL strings gracefully.
+ *
+ * Returns: -1, 0 or 1, if @str1 is <, == or > than @str2.
+ *
+ * Since: 2.16
  */
 int
 g_strcmp0 (const char     *str1,
@@ -1329,17 +1385,6 @@ g_string_write_out (GString *gstring,
     }
 }
 
-static int
-sane_dup2 (int fd1,
-           int fd2)
-{
-  int ret;
-  do
-    ret = dup2 (fd1, fd2);
-  while (ret < 0 && errno == EINTR);
-  return ret;
-}
-
 static void
 test_trap_clear (void)
 {
@@ -1351,6 +1396,19 @@ test_trap_clear (void)
   test_trap_last_stderr = NULL;
 }
 
+#ifdef G_OS_UNIX
+
+static int
+sane_dup2 (int fd1,
+           int fd2)
+{
+  int ret;
+  do
+    ret = dup2 (fd1, fd2);
+  while (ret < 0 && errno == EINTR);
+  return ret;
+}
+
 static guint64
 test_time_stamp (void)
 {
@@ -1362,6 +1420,8 @@ test_time_stamp (void)
   return stamp;
 }
 
+#endif
+
 /**
  * g_test_trap_fork:
  * @usec_timeout:    Timeout for the forked test in micro seconds.
@@ -1386,7 +1446,7 @@ test_time_stamp (void)
  * In the following example, the test code forks, the forked child
  * process produces some sample output and exits successfully.
  * The forking parent process then asserts successfull child program
- * termination and validates cihld program outputs.
+ * termination and validates child program outputs.
  *
  * |[
  *   static void
@@ -1404,7 +1464,11 @@ test_time_stamp (void)
  *   }
  * ]|
  *
+ * This function is implemented only on Unix platforms.
+ *
  * Returns: %TRUE for the forked child and %FALSE for the executing parent process.
+ *
+ * Since: 2.16
  */
 gboolean
 g_test_trap_fork (guint64        usec_timeout,
@@ -1541,16 +1605,20 @@ g_test_trap_fork (guint64        usec_timeout,
       return FALSE;
     }
 #else
-  g_error ("Not implemented: g_test_trap_fork");
+  g_message ("Not implemented: g_test_trap_fork");
+
+  return FALSE;
 #endif
 }
 
 /**
  * g_test_trap_has_passed:
  *
- * Check the reuslt of the last g_test_trap_fork() call.
+ * Check the result of the last g_test_trap_fork() call.
  *
  * Returns: %TRUE if the last forked child terminated successfully.
+ *
+ * Since: 2.16
  */
 gboolean
 g_test_trap_has_passed (void)
@@ -1561,9 +1629,11 @@ g_test_trap_has_passed (void)
 /**
  * g_test_trap_reached_timeout:
  *
- * Check the reuslt of the last g_test_trap_fork() call.
+ * Check the result of the last g_test_trap_fork() call.
  *
  * Returns: %TRUE if the last forked child got killed due to a fork timeout.
+ *
+ * Since: 2.16
  */
 gboolean
 g_test_trap_reached_timeout (void)
@@ -1579,6 +1649,7 @@ g_test_trap_assertions (const char     *domain,
                         guint64         assertion_flags, /* 0-pass, 1-fail, 2-outpattern, 4-errpattern */
                         const char     *pattern)
 {
+#ifdef G_OS_UNIX
   gboolean must_pass = assertion_flags == 0;
   gboolean must_fail = assertion_flags == 1;
   gboolean match_result = 0 == (assertion_flags & 1);
@@ -1611,6 +1682,7 @@ g_test_trap_assertions (const char     *domain,
       g_assertion_message (domain, file, line, func, msg);
       g_free (msg);
     }
+#endif
 }
 
 static void
@@ -1812,16 +1884,19 @@ g_test_log_msg_free (GTestLogMsg *tmsg)
  * g_test_add:
  * @testpath:  The test path for a new test case.
  * @Fixture:   The type of a fixture data structure.
+ * @tdata:     Data argument for the test functions.
  * @fsetup:    The function to set up the fixture data.
  * @ftest:     The actual test function.
  * @fteardown: The function to tear down the fixture data.
  *
  * Hook up a new test case at @testpath, similar to g_test_add_func().
  * A fixture data structure with setup and teardown function may be provided
- * though, simmilar to g_test_create_case().
+ * though, similar to g_test_create_case().
  * g_test_add() is implemented as a macro, so that the fsetup(), ftest() and
  * fteardown() callbacks can expect a @Fixture pointer as first argument in
  * a type safe manner.
+ *
+ * Since: 2.16
  **/
 /* --- macros docs END --- */
 
